@@ -4,7 +4,7 @@
 
     RSS feed generator for blog. 
 
-    :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
+    :copyright: Copyright 2011-2013 by Vlad Riscutia and contributors (see
     CONTRIBUTORS file)
     :license: FreeBSD, see LICENSE file
 '''
@@ -60,7 +60,7 @@ def generate_feed(app):
     # feed metadata 
     context["title"] = app.config.project
     context["link"] = app.config.website
-    context["description"] = app.config.tagline
+    context["tagline"] = app.config.tagline
     context["language"] = "en-us"
   
     # feed pubDate is equal to latest post pubDate
