@@ -4,12 +4,13 @@
 
     Tinkerer path information.
 
-    :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
+    :copyright: Copyright 2011-2013 by Vlad Riscutia and contributors (see
     CONTRIBUTORS file)
     :license: FreeBSD, see LICENSE file
 '''
 import os
 import tinkerer
+import sys
 
 
 # package path
@@ -22,6 +23,11 @@ themes = os.path.join(__package_path, "themes")
 static = os.path.join(__package_path, "static")
 
 
+# add "./exts" path to os search path so Sphinx can pick up any extensions
+# from there
+sys.path.append(os.path.abspath("./_exts"))
+
+
 def set_paths(root_path="."):
     '''
     Computes required relative paths based on given root path.
